@@ -99,7 +99,7 @@ class Betting(BaseEndpoint):
             assert region_id is not None
 
         (response, response_json, elapsed_time) = self._request(
-            method_uri=f"{self.api_version}/active_fixtures/{sport_id}/{region_id if region_id else ''}{f'/{competition_id}' if competition_id is not None else ''}",
+            method_uri=f"{self.api_version}/active_fixtures/{sport_id}/{region_id if region_id else ''}{f'/{competition_id}' if competition_id is not None else ''}"
         )
 
         return self.process_response(
@@ -194,7 +194,10 @@ class Betting(BaseEndpoint):
         self, request_filter: resources.GetBetRequestFilter
     ) -> Union[resources.BaseRequestException, resources.BetRequest]:
         """
-        Gets a bet request for the given filter
+        Gets a bet request for the given filter.
+
+        This is other users bet requests (please use get_active_bet_requests / my_bets ) to get your own.
+
         :param request_filter: A bet request filter, either enter a bet request id or other filter values
         :return: A bet BetRequest resource or an BaseRequestException when BetConnect detects an issue.
         """
@@ -213,10 +216,20 @@ class Betting(BaseEndpoint):
                 ),
             )
         else:
-            (response, response_json, elapsed_time) = self._post(
-                method_uri=f"{self.api_version}/bet_request_get",
-                data=request_filter.generate_request_data(exclude={"bet_request_id"}),
-            )
+            if request_filter.accept_each_way:
+                (response, response_json, elapsed_time) = self._post(
+                    method_uri=f"{self.api_version}/bet_request_get",
+                    data=request_filter.generate_request_data(
+                        exclude={"bet_request_id", "accept_each_way"}
+                    ),
+                )
+            else:
+                (response, response_json, elapsed_time) = self._post(
+                    method_uri=f"{self.api_version}/bet_request_get",
+                    data=request_filter.generate_request_data(
+                        exclude={"bet_request_id"}
+                    ),
+                )
 
         return self.process_response(
             response=response,
@@ -254,7 +267,7 @@ class Betting(BaseEndpoint):
         :return: A List of SelectionsForMarket resources or an BaseRequestException when BetConnect detects an issue.
         """
         (response, response_json, elapsed_time) = self._request(
-            method_uri=f"{self.api_version}/selections_for_market/{fixture_id}/{market_type_id}{f'/top_price_only'if top_price_only else ''}"
+            method_uri=f"{self.api_version}/selections_for_market/{fixture_id}/{market_type_id}/{f'True'if top_price_only else 'False'}"
         )
         # Check is response a line market
         if self._is_line_market(response=response, response_json=response_json):
@@ -483,7 +496,11 @@ class Betting(BaseEndpoint):
         page: int = None,
         get_all: str = None,
         customer_strategy_ref: str = None,
-    ) -> Union[resources.MyBetsBetRequests, resources.BaseRequestException]:
+    ) -> Union[
+        resources.MyBetsBetRequests,
+        resources.MyBetsBets,
+        resources.BaseRequestException,
+    ]:
         """
         Returns a list of MyBets allowing for per strategy recall of bets
         :param side: the side of the bet, enum value BACK and LAY
@@ -541,12 +558,20 @@ class Betting(BaseEndpoint):
             authenticated=True,
         )
 
-        return self.process_response(
-            response=response,
-            response_json=response_json,
-            resource=resources.MyBetsBetRequests,
-            elapsed_time=elapsed_time,
-        )
+        if side.value == "back":
+            return self.process_response(
+                response=response,
+                response_json=response_json,
+                resource=resources.MyBetsBetRequests,
+                elapsed_time=elapsed_time,
+            )
+        else:
+            return self.process_response(
+                response=response,
+                response_json=response_json,
+                resource=resources.MyBetsBets,
+                elapsed_time=elapsed_time,
+            )
 
     def lock_bet(
         self, bet_request_id: UUID, bet_status_id: int, allocated_stake: int
