@@ -20,9 +20,9 @@ from .betting import (
     Viewed,
     BetRequestMatchMore,
     PricesBookmaker,
-    BackersStats,
     MyActiveBet,
     MyBetsBetRequests,
+    MyBetsBets,
     BetRequestStop,
     CustomerOrderRef,
     CustomerStrategyRef,
